require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sqldatabaseuser',
  dscmeta_resource_friendly_name: 'SqlDatabaseUser',
  dscmeta_resource_name: 'DSC_SqlDatabaseUser',
  dscmeta_module_name: 'SqlServerDsc',
  dscmeta_module_version: '14.2.1',
  docs: %q{
    The DSC SqlDatabaseUser resource type.
    Automatically generated from version 14.2.1
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_force: {
      type: "Optional[Boolean]",
      desc: %q{
        Specifies if it is allowed to re-create the database user if either the user type, the asymmetric key, or the certificate changes. Default value is `$false` not allowing database users to be re-created.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: "String",
      desc: %q{
        Specifies the name of the database user to be added or removed.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_loginname: {
      type: "Optional[String]",
      desc: %q{
        Specifies the name of the login to associate with the database user. This must be specified if parameter **UserType** is set to `'Login'`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatename: {
      type: "Optional[String]",
      desc: %q{
        Specifies the name of the certificate to associate with the database user. This must be specified if parameter **UserType** is set to `'Certificate'`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: %q{
        Specifies if the database user should be present or absent. If `'Present'` then the database user will be added to the database and, if needed, the login mapping will be updated. If `'Absent'` then the database user will be removed from the database. Default value is `'Present'`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_servername: {
      type: "Optional[String]",
      desc: %q{
        Specifies the host name of the _SQL Server_ on which the instance exist. Default value is `$env:COMPUTERNAME`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_instancename: {
      type: "String",
      desc: %q{
        Specifies the _SQL Server_ instance in which the database exist.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databasename: {
      type: "String",
      desc: %q{
        Specifies the name of the database in which to configure the database user.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_asymmetrickeyname: {
      type: "Optional[String]",
      desc: %q{
        Specifies the name of the asymmetric key to associate with the database user. This must be specified if parameter **UserType** is set to `'AsymmetricKey'`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usertype: {
      type: "Optional[Enum['Login', 'NoLogin', 'Certificate', 'AsymmetricKey']]",
      desc: %q{
        Specifies the type of the database user. Default value is `'NoLogin'`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
