require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sqlmemory',
  dscmeta_resource_friendly_name: 'SqlMemory',
  dscmeta_resource_name: 'DSC_SqlMemory',
  dscmeta_module_name: 'SqlServerDsc',
  dscmeta_module_version: '14.2.1',
  docs: %q{
    The DSC SqlMemory resource type.
    Automatically generated from version 14.2.1
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_servername: {
      type: "Optional[String]",
      desc: %q{
        The host name of the _SQL Server_ to be configured. Default value is `$env:COMPUTERNAME`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_instancename: {
      type: "String",
      desc: %q{
        The name of the _SQL Server_ instance to be configured.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: %q{
        When set to `'Present'` then min and max memory will be set to either the value in parameter **MinMemory** and **MaxMemory**, or dynamically configured when parameter **DynamicAlloc** is set to `$true`. When set to `'Absent'` min and max memory will be set to its default values. Default value is `'Present'`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dynamicalloc: {
      type: "Optional[Boolean]",
      desc: %q{
        If set to `$true` then max memory will be dynamically configured. When this parameter is set to `$true`, the parameter **MaxMemory** must be set to `$null` or not be configured. Default value is `$false`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxmemory: {
      type: "Optional[Integer[-2147483648, 2147483647]]",
      desc: %q{
        Maximum amount of memory, in MB, in the buffer pool used by the instance of _SQL Server_.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_processonlyonactivenode: {
      type: "Optional[Boolean]",
      desc: %q{
        Specifies that the resource will only determine if a change is needed if the target node is the active host of the _SQL Server_ instance.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_minmemory: {
      type: "Optional[Integer[-2147483648, 2147483647]]",
      desc: %q{
        Minimum amount of memory, in MB, in the buffer pool used by the instance of _SQL Server_.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
  },
)
