require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sqlprotocoltcpip',
  dscmeta_resource_friendly_name: 'SqlProtocolTcpIp',
  dscmeta_resource_name: 'DSC_SqlProtocolTcpIp',
  dscmeta_module_name: 'SqlServerDsc',
  dscmeta_module_version: '14.2.1',
  docs: %q{
    The DSC SqlProtocolTcpIp resource type.
    Automatically generated from version 14.2.1
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enabled: {
      type: "Optional[Boolean]",
      desc: %q{
        Specified if the IP address group should be enabled or disabled. Only used if the parameter **IpAddressGroup** is _not_ set to `'IPAll'`. If not specified, the existing value will not be changed.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_instancename: {
      type: "String",
      desc: %q{
        Specifies the name of the _SQL Server_ instance to manage the IP address group for.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usetcpdynamicport: {
      type: "Optional[Boolean]",
      desc: %q{
        Specifies whether the _SQL Server_ instance should use a dynamic port. If not specified, the existing value will not be changed. This parameter is not allowed to be used at the same time as the parameter **TcpPort**.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_servername: {
      type: "Optional[String]",
      desc: %q{
        Specifies the host name of the _SQL Server_ to be configured. If the _SQL Server_ belongs to a cluster or availability group specify the host name for the listener or cluster group. Default value is `$env:COMPUTERNAME`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ipaddressgroup: {
      type: "String",
      desc: %q{
        Specifies the name of the IP address group in the TCP/IP protocol, e.g. `'IP1'`, `'IP2'` etc., or `'IPAll'`.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_suppressrestart: {
      type: "Optional[Boolean]",
      desc: %q{
        If set to `$true` then the any attempt by the resource to restart the service is suppressed. The default value is `$false`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tcpport: {
      type: "Optional[String]",
      desc: %q{
        Specifies the TCP port(s) that _SQL Server_ instance should be listening on. If the IP address should listen on more than one port, list all ports as a string value with the port numbers separated with a comma, e.g. `'1433,1500,1501'`. This parameter is limited to 2047 characters. If not specified, the existing value will not be changed. This parameter is not allowed to be used at the same time as the parameter **UseTcpDynamicPort**.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_restarttimeout: {
      type: "Optional[Integer[0, 65535]]",
      desc: %q{
        Timeout value for restarting the _SQL Server_ services. The default value is `120` seconds.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_ipaddress: {
      type: "Optional[String]",
      desc: %q{
        Specifies the IP address for the IP address group. Only used if the parameter **IpAddressGroup** is _not_ set to `'IPAll'`. If not specified, the existing value will not be changed.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
