require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sqlreplication',
  dscmeta_resource_friendly_name: 'SqlReplication',
  dscmeta_resource_name: 'DSC_SqlReplication',
  dscmeta_module_name: 'SqlServerDsc',
  dscmeta_module_version: '14.2.1',
  docs: %q{
    The DSC SqlReplication resource type.
    Automatically generated from version 14.2.1
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_workingdirectory: {
      type: "String",
      desc: %q{
        Publisher working directory.
      },

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_distributiondbname: {
      type: "Optional[String]",
      desc: %q{
        Distribution database name. If the parameter **DistributionMode**  is set to `'Local'` this will be created, if `'Remote'` needs to match distribution database on remote distributor. Default value is `'distributor'`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_uninstallwithforce: {
      type: "Optional[Boolean]",
      desc: %q{
        Force flag for uninstall procedure. Default values is `$trueÂ´.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_instancename: {
      type: "String",
      desc: %q{
        Specifies the _SQL Server_ instance name where replication distribution will be configured.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: %q{
        `'Present'` will configure replication, `'Absent'` will disable (remove) replication. Default value is `'Present'`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_adminlinkcredentials: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{
        AdminLink password to be used when setting up publisher distributor relationship.
      },

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_remotedistributor: {
      type: "Optional[String]",
      desc: %q{
        Specifies the _SQL Server_ network name that will be used as distributor for local instance. Required if parameter **DistributionMode**  is set to `'Remote'`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_distributormode: {
      type: "Enum['Local', 'Remote']",
      desc: %q{
        `'Local'` - Instance will be configured as it's own distributor. `'Remote'` - Instance will be configure with remote distributor (remote distributor needs to be already configured for distribution).
      },

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usetrustedconnection: {
      type: "Optional[Boolean]",
      desc: %q{
        Publisher security mode. Default value is `$true`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
