require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sqlrssetup',
  dscmeta_resource_friendly_name: 'SqlRSSetup',
  dscmeta_resource_name: 'DSC_SqlRSSetup',
  dscmeta_module_name: 'SqlServerDsc',
  dscmeta_module_version: '14.2.1',
  docs: %q{
    The DSC SqlRSSetup resource type.
    Automatically generated from version 14.2.1
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_action: {
      type: "Optional[Enum['Install', 'Uninstall']]",
      desc: %q{
        The action to be performed. Default value is `'Install'` which performs either install or upgrade.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_versionupgrade: {
      type: "Optional[Boolean]",
      desc: %q{
        Upgrades installed product version if the major product version of the source executable is higher than the currently installed major version. Requires that either the **ProductKey** or the **Edition** parameter is also assigned. Default is `$false`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_editionupgrade: {
      type: "Optional[Boolean]",
      desc: %q{
        Upgrades the edition of the installed product. Requires that either the **ProductKey** or the **Edition** parameter is also assigned. By default no edition upgrade is performed.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sourcecredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{
        Credentials used to access the path set in the parameter **SourcePath**.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_iacceptlicenseterms: {
      type: "Enum['Yes']",
      desc: %q{
        Accept licens terms. This must be set to `'Yes'`.
      },

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sourcepath: {
      type: "String",
      desc: %q{
        The path to the installation media file to be used for installation, e.g an UNC path to a shared resource. Environment variables can be used in the path.
      },

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_instancename: {
      type: "Enum['SSRS']",
      desc: %q{
        Name of the _Microsoft SQL Server Reporting Service_ instance to installed. This can only be set to `'SSRS'`.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_edition: {
      type: "Optional[Enum['Development', 'Evaluation', 'ExpressAdvanced']]",
      desc: %q{
        Sets the custom free edition. This parameter is mutually exclusive with the parameter **ProductKey**.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_productkey: {
      type: "Optional[String]",
      desc: %q{
        Sets the custom license key, e.g. `'12345-12345-12345-12345-12345'`. This parameter is mutually exclusive with the parameter **Edition**.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_installfolder: {
      type: "Optional[String]",
      desc: %q{
        Sets the install folder, e.g. `C:\Program Files\SSRS`. Default value is `C:\Program Files\Microsoft SQL Server Reporting Services`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_forcerestart: {
      type: "Optional[Boolean]",
      desc: %q{
        Forces a restart after installation is finished. If set to `$true` then it will override the parameter **SuppressRestart**.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_setupprocesstimeout: {
      type: "Optional[Integer[0, 4294967295]]",
      desc: %q{
        The timeout, in seconds, to wait for the setup process to finish. Default value is `7200` seconds (2 hours). If the setup process does not finish before this time an error will be thrown.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_suppressrestart: {
      type: "Optional[Boolean]",
      desc: %q{
        Suppresses any attempts to restart.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_logpath: {
      type: "Optional[String]",
      desc: %q{
        Specifies the setup log file location, e.g. `log.txt`. By default log files are created under `%TEMP%`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
