require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sqlserviceaccount',
  dscmeta_resource_friendly_name: 'SqlServiceAccount',
  dscmeta_resource_name: 'DSC_SqlServiceAccount',
  dscmeta_module_name: 'SqlServerDsc',
  dscmeta_module_version: '14.2.1',
  docs: %q{
    The DSC SqlServiceAccount resource type.
    Automatically generated from version 14.2.1
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_servername: {
      type: "Optional[String]",
      desc: %q{
        The host name of the _SQL Server_ to be configured. Default value is `$env:COMPUTERNAME`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_restartservice: {
      type: "Optional[Boolean]",
      desc: %q{
        Determines whether the service is automatically restarted when a change to the configuration was needed.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_versionnumber: {
      type: "Optional[String]",
      desc: %q{
        The version number for the service type to be managed for the instance that is specified in parameter **InstanceName**. Mandatory when parameter **ServiceType** is set to `'IntegrationServices'`.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_instancename: {
      type: "String",
      desc: %q{
        The name of the _SQL Server_ instance to be configured.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_servicetype: {
      type: "Enum['DatabaseEngine', 'SQLServerAgent', 'Search', 'IntegrationServices', 'AnalysisServices', 'ReportingServices', 'SQLServerBrowser', 'NotificationServices']",
      desc: %q{
        The service type to be managed for the instance that is specified in parameter **InstanceName**.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_force: {
      type: "Optional[Boolean]",
      desc: %q{
        Forces the service account to be updated. Useful for password changes. This will cause _Set_ to be run on each consecutive run.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_serviceaccount: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{
        The service account that should be used when running the _Windows_ service.
      },

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
