require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sqlwaitforag',
  dscmeta_resource_friendly_name: 'SqlWaitForAG',
  dscmeta_resource_name: 'DSC_SqlWaitForAG',
  dscmeta_module_name: 'SqlServerDsc',
  dscmeta_module_version: '14.2.1',
  docs: %q{
    The DSC SqlWaitForAG resource type.
    Automatically generated from version 14.2.1
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_retryintervalsec: {
      type: "Optional[Integer[0, 18446744073709551615]]",
      desc: %q{
        The interval, in seconds, to check for the presence of the cluster role/group. Default value is `20` seconds. When the cluster role/group has been found the resource will wait for this amount of time once more before returning.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_retrycount: {
      type: "Optional[Integer[0, 4294967295]]",
      desc: %q{
        Maximum number of retries until the resource will timeout and throw an error. Default values is `30` times.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: "String",
      desc: %q{
        Name of the cluster role/group to look for (normally the same as the _Availability Group_ name).
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
